Autosubmit Log — autosubmit 3.9.1 documentation

# Autosubmit Log

When you click on the `Log` tab, you will see the button `Show Log`:

47 Experiment Log

Important

The main Autosubmit log is usually stored in the folder `/tmp/` of your experiment, and this is the first path the system will scan.

When you click on the `Show Log` button, the last 150 lines of the log will be displayed:

48 Experiment Log Open

At the top of the log you will see the name of the log file that is being displayed along with the timestamp of the last time the log was requested, and to the right you see this timestamp in `datetime` format.

If the experiment is currently running, the log will be updated periodically to keep you up with recent updates in the experiment execution. It is possible to scroll this view.

If you click on `Hide Log` the log will be cleared and the periodic updates will stop.